# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['investiny']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.23.0,<0.24.0']

setup_kwargs = {
    'name': 'investiny',
    'version': '0.1.0',
    'description': '`investpy` but made tiny.',
    'long_description': '# 🤏🏻 `investpy` but made tiny\n\nSuuuuuuuper simple and tiny `investpy` replacement while I try to fix it! Here I\'ll try\nto add more or less the same functionality that was developed for `investpy` while keeping this\npackage tiny and up-to-date, as some solutions just work temporarily.\n\nEveryone using `investiny` please go thank @ramakrishnamekala129 for proposing this solution\nthat seems to be stable and working fine so far (fingers crossed!). Also take the chance to explore\nany other solution proposed by the `investpy` users at https://github.com/alvarobartt/investpy/issues.\n\nI\'m currently waiting to have a conversation with Investing.com so as to see whether we can get\nto some sort of an agreement in order to keep `investpy` alive.\n\nIn the meantime you can follow me at https://twitter.com/alvarobartt as I post updates there, and\nI highly appreciate your feedback.\n\n@adelRosal, an `investpy` user created a change.org site so as to show some support, so please sign\nthe petition as it may be useful towards the continuity of `investpy` at https://www.change.org/p/support-from-investing-com-for-the-continuity-of-investpy-library\n\nFinally, remember that `investiny` is super simple and tiny and shouldn\'t be considered reliable, it\'s\nworking fine so far, but it may be discontinued, so please use it carefully.\n\n## 🤏🏻 Usage\n\n```python\nfrom investiny import historical_data\n\ndata = historical_data(investing_id=6408, from_date="09/01/2022", to_date="10/01/2022") # Returns AAPL historical data as JSON (without date)\n```\n\n## 🔮 TODOs\n\n- [ ] Add Search API as also available https://tvc4.investing.com/.../search?limit=30&query=USD&type=&exchange= (thanks again @ramakrishnamekala129)\n- [ ] Add error basic error handling\n',
    'author': 'Alvaro Bartolome',
    'author_email': 'alvarobartt@yahoo.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/alvarobartt/investiny',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



# Copyright 2022 Alvaro Bartolome, alvarobartt @ GitHub
# See LICENSE for details.

import json
from datetime import datetime
from typing import Any, Dict, Literal
from uuid import uuid4

import httpx

__all__ = ["historical_data"]


def historical_data(
    investing_id: int,
    from_date: str,
    to_date: str,
    interval: Literal["D", "W", "M"] = "D",
) -> Dict[str, Any]:
    """Get historical data from Investing.com.

    Args:
        investing_id (int): Investing.com's ID for the asset.
        from_date (str): Initial date to retrieve historical data (formatted as m/d/Y).
        to_date (str): Final date to retrieve historical data (formatted as m/d/Y).

    Returns:
        Dict[str, Any]: A dictionary with the historical data.
    """
    url = f"https://tvc4.investing.com/{uuid4().hex}/0/0/0/0/history"
    headers = {
        "User-Agent": (
            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like"
            " Gecko) Chrome/104.0.5112.102 Safari/537.36"
        ),
        "Referer": "https://tvc-invdn-com.investing.com/",
        "Content-Type": "application/json",
    }
    params = {
        "symbol": investing_id,
        "from": int(datetime.strptime(from_date, "%m/%d/%Y").timestamp()),
        "to": int(datetime.strptime(to_date, "%m/%d/%Y").timestamp()),
        "resolution": interval,
    }
    r = httpx.get(url, params=params, headers=headers)
    data = json.loads(r.text)
    return {
        "open": data["o"],
        "high": data["h"],
        "low": data["l"],
        "close": data["c"],
    }



# Copyright 2022 Alvaro Bartolome, alvarobartt @ GitHub
# See LICENSE for details.

"""`investiny `: `investpy` but made tiny."""

__author__ = "Alvaro Bartolome, alvarobartt @ GitHub"
__version__ = "0.1.0"

from investiny.historical import historical_data  # noqa: F401
